@@ -4,9 +4,28 @@ from .models import SymbolInfo
 
 
 class StockInfo:
-    def __init__(self):        
+    def __init__(self):
         self._markets_info = ExternalApiAccess.get_market_data()
 
+    def get_symbols(self):
+        """
+        Get all available symbols
+        """
+        results = []        
+        
+        if self._markets_info is not None:
+            for market_info in self._markets_info:
+                for symbol_data in market_info.data:
+                    try:
+                        result = Mappers.map_api_results_to_symbol_info_basic(market_info, symbol_data)
+                        if result is not None:
+                            # Get first available symbol result in any market
+                            results.append(result)
+                    except Exception as ex:
+                        print(f"Error retrieving market data - {ex}")
+        
+        return results 
+
     def get_symbol_info(self, symbol: str) -> SymbolInfo:
         """
         Get single symbol info
