@@ -20,12 +20,18 @@ class MarketInfo:
     type: str
     data: Optional[dict] = None
     field_average_percentage_change: Optional[str] = None
+    field_description: Optional[str] = None
     content_type: Optional[str] = "application/json"
     request_info_params: Optional[dict] = None
 
 @dataclass
-class SymbolInfo:
+class SymbolInfoBasic:
     market_name: str
+    description: str
+    symbol: str
+
+
+@dataclass
+class SymbolInfo(SymbolInfoBasic):
     average_percentage_change: str
     latest_price: str
-    symbol: str
\ No newline at end of file
